matchz

package
v0.0.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrNoMatches = errors.New("no matches")

Functions

This section is empty.

Types

type CorrelationT

type CorrelationT struct {
	Field    string `msg:"field"`
	StrValue string `msg:"strv"`
	IntValue int64  `msg:"intv"`
}

func (*CorrelationT) DecodeMsg

func (z *CorrelationT) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (CorrelationT) EncodeMsg

func (z CorrelationT) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (CorrelationT) MarshalMsg

func (z CorrelationT) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (CorrelationT) Msgsize

func (z CorrelationT) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*CorrelationT) UnmarshalMsg

func (z *CorrelationT) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type EntityMetadataT

type EntityMetadataT struct {
	ProcessId     uint32 `msg:"pid"`
	MachineId     string `msg:"mid"`
	CgroupId      string `msg:"cgrp"`
	ContainerId   string `msg:"cid"`
	PodName       string `msg:"pod"`
	HostName      string `msg:"host"`
	Namespace     string `msg:"ns"`
	FileName      string `msg:"fname"`
	ProcessName   string `msg:"pname"`
	ImageUrl      string `msg:"imgurl"`
	ContainerName string `msg:"cname"`
	Origin        bool   `msg:"orig"`
}

func (*EntityMetadataT) DecodeMsg

func (z *EntityMetadataT) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (*EntityMetadataT) EncodeMsg

func (z *EntityMetadataT) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (*EntityMetadataT) MarshalMsg

func (z *EntityMetadataT) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (*EntityMetadataT) Msgsize

func (z *EntityMetadataT) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*EntityMetadataT) UnmarshalMsg

func (z *EntityMetadataT) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type EntryT

type EntryT struct {
	Timestamp int64  `msg:"ts"`
	Entry     []byte `msg:"entry"`
	SpoolIdx  int64  `msg:"spidx"`
}

func (*EntryT) DecodeMsg

func (z *EntryT) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (*EntryT) EncodeMsg

func (z *EntryT) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (*EntryT) MarshalMsg

func (z *EntryT) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (*EntryT) Msgsize

func (z *EntryT) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*EntryT) UnmarshalMsg

func (z *EntryT) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type HitsT

type HitsT struct {
	Count        uint32          `msg:"cnt"`
	Entries      []EntryT        `msg:"entries"`
	Correlations []CorrelationT  `msg:"corrs"`
	Entity       EntityMetadataT `msg:"entity"`
}

func (*HitsT) DecodeMsg

func (z *HitsT) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (*HitsT) EncodeMsg

func (z *HitsT) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (*HitsT) MarshalMsg

func (z *HitsT) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (*HitsT) Msgsize

func (z *HitsT) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (HitsT) Timestamp

func (h HitsT) Timestamp() (int64, error)

Return first timestamp

func (*HitsT) UnmarshalMsg

func (z *HitsT) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type MatchesT

type MatchesT struct {
	Timestamp int64  `msg:"ts"`
	SpoolIdx  int64  `msg:"spidx"`
	RuleId    string `msg:"rid"`
	RuleHash  string `msg:"rhash"`
	MatchId   uint32 `msg:"matchid"`
	Depth     uint32 `msg:"depth"`
	NodeType  string `msg:"ntype"`
	Hits      HitsT  `msg:"hits"`
}

func (*MatchesT) DecodeMsg

func (z *MatchesT) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (*MatchesT) EncodeMsg

func (z *MatchesT) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (*MatchesT) MarshalMsg

func (z *MatchesT) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (*MatchesT) Msgsize

func (z *MatchesT) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*MatchesT) UnmarshalMsg

func (z *MatchesT) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

Jump to