Documentation
¶
Index ¶
- Variables
- type CorrelationT
- type EntityMetadataT
- func (z *EntityMetadataT) DecodeMsg(dc *msgp.Reader) (err error)
- func (z *EntityMetadataT) EncodeMsg(en *msgp.Writer) (err error)
- func (z *EntityMetadataT) MarshalMsg(b []byte) (o []byte, err error)
- func (z *EntityMetadataT) Msgsize() (s int)
- func (z *EntityMetadataT) UnmarshalMsg(bts []byte) (o []byte, err error)
- type EntryT
- type HitsT
- func (z *HitsT) DecodeMsg(dc *msgp.Reader) (err error)
- func (z *HitsT) EncodeMsg(en *msgp.Writer) (err error)
- func (z *HitsT) MarshalMsg(b []byte) (o []byte, err error)
- func (z *HitsT) Msgsize() (s int)
- func (h HitsT) Timestamp() (int64, error)
- func (z *HitsT) UnmarshalMsg(bts []byte) (o []byte, err error)
- type MatchesT
Constants ¶
This section is empty.
Variables ¶
var ErrNoMatches = errors.New("no matches")
Functions ¶
This section is empty.
Types ¶
type CorrelationT ¶
type CorrelationT struct {
Field string `msg:"field"`
StrValue string `msg:"strv"`
IntValue int64 `msg:"intv"`
}
func (*CorrelationT) DecodeMsg ¶
func (z *CorrelationT) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (CorrelationT) EncodeMsg ¶
func (z CorrelationT) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (CorrelationT) MarshalMsg ¶
func (z CorrelationT) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (CorrelationT) Msgsize ¶
func (z CorrelationT) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*CorrelationT) UnmarshalMsg ¶
func (z *CorrelationT) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler
type EntityMetadataT ¶
type EntityMetadataT struct {
ProcessId uint32 `msg:"pid"`
MachineId string `msg:"mid"`
CgroupId string `msg:"cgrp"`
ContainerId string `msg:"cid"`
PodName string `msg:"pod"`
HostName string `msg:"host"`
Namespace string `msg:"ns"`
FileName string `msg:"fname"`
ProcessName string `msg:"pname"`
ImageUrl string `msg:"imgurl"`
ContainerName string `msg:"cname"`
Origin bool `msg:"orig"`
}
func (*EntityMetadataT) DecodeMsg ¶
func (z *EntityMetadataT) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (*EntityMetadataT) EncodeMsg ¶
func (z *EntityMetadataT) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (*EntityMetadataT) MarshalMsg ¶
func (z *EntityMetadataT) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (*EntityMetadataT) Msgsize ¶
func (z *EntityMetadataT) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*EntityMetadataT) UnmarshalMsg ¶
func (z *EntityMetadataT) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler
type EntryT ¶
type EntryT struct {
Timestamp int64 `msg:"ts"`
Entry []byte `msg:"entry"`
SpoolIdx int64 `msg:"spidx"`
}
func (*EntryT) MarshalMsg ¶
MarshalMsg implements msgp.Marshaler
type HitsT ¶
type HitsT struct {
Count uint32 `msg:"cnt"`
Entries []EntryT `msg:"entries"`
Correlations []CorrelationT `msg:"corrs"`
Entity EntityMetadataT `msg:"entity"`
}
func (*HitsT) MarshalMsg ¶
MarshalMsg implements msgp.Marshaler
type MatchesT ¶
type MatchesT struct {
Timestamp int64 `msg:"ts"`
SpoolIdx int64 `msg:"spidx"`
RuleId string `msg:"rid"`
RuleHash string `msg:"rhash"`
MatchId uint32 `msg:"matchid"`
Depth uint32 `msg:"depth"`
NodeType string `msg:"ntype"`
Hits HitsT `msg:"hits"`
}
func (*MatchesT) MarshalMsg ¶
MarshalMsg implements msgp.Marshaler
Click to show internal directories.
Click to hide internal directories.